@@ -127,8 +127,8 @@ static QWidget *createSelectableLineEditOptionHandle(QObject *opt)
     };
 
     option->connect(le, &DLineEdit::iconClicked, [=]() {
-        QString name = QFileDialog::getExistingDirectory(0, QObject::tr("Open Folder"),
-                QDir::currentPath(),
+        QString name = QFileDialog::getExistingDirectory(0, QObject::tr("Open folder"),
+                MainWindow::lastOpenedPath(),
                 QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
         if (validate(name, false)) {
             option->setValue(name);
@@ -1446,12 +1446,14 @@ void MainWindow::requestAction(ActionFactory::ActionKind kd, bool fromUI,
         }
 
         case ActionFactory::ActionKind::OpenDirectory: {
-            QString name = QFileDialog::getExistingDirectory(this, tr("Open Folder"),
-                    QDir::currentPath(),
+            QString name = QFileDialog::getExistingDirectory(this, tr("Open folder"),
+                    lastOpenedPath(),
                     QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
 
             QFileInfo fi(name);
             if (fi.isDir() && fi.exists()) {
+                Settings::get().setGeneralOption("last_open_path", fi.path());
+
                 const auto& urls = _engine->addPlayDir(name);
                 if (urls.size()) {
                     _engine->playByName(QUrl("playlist://0"));
@@ -1461,13 +1463,18 @@ void MainWindow::requestAction(ActionFactory::ActionKind kd, bool fromUI,
         }
 
         case ActionFactory::ActionKind::OpenFileList: {
-            QStringList filenames = QFileDialog::getOpenFileNames(this, tr("Open File"),
-                    QDir::currentPath(),
+            QStringList filenames = QFileDialog::getOpenFileNames(this, tr("Open file"),
+                    lastOpenedPath(),
                     tr("All videos (%1)").arg(_engine->video_filetypes.join(" ")), 0,
                     QFileDialog::HideNameFilterDetails);
 
             QList<QUrl> urls;
             if (filenames.size()) {
+                QFileInfo fileInfo(filenames[0]);
+                if (fileInfo.exists()) {
+                    Settings::get().setGeneralOption("last_open_path", fileInfo.path());
+                }
+
                 for (const auto& filename: filenames) {
                     urls.append(QUrl::fromLocalFile(filename));
                 }
@@ -1478,11 +1485,14 @@ void MainWindow::requestAction(ActionFactory::ActionKind kd, bool fromUI,
         }
 
         case ActionFactory::ActionKind::OpenFile: {
-            QString filename = QFileDialog::getOpenFileName(this, tr("Open File"),
-                    QDir::currentPath(),
+            QString filename = QFileDialog::getOpenFileName(this, tr("Open file"),
+                    lastOpenedPath(),
                     tr("All videos (%1)").arg(_engine->video_filetypes.join(" ")), 0,
                     QFileDialog::HideNameFilterDetails);
-            if (QFileInfo(filename).exists()) {
+            QFileInfo fileInfo(filename);
+            if (fileInfo.exists()) {
+                Settings::get().setGeneralOption("last_open_path", fileInfo.path());
+
                 play(QUrl::fromLocalFile(filename));
             }
             break;
@@ -1813,9 +1823,9 @@ void MainWindow::requestAction(ActionFactory::ActionKind kd, bool fromUI,
         }
 
         case ActionFactory::ActionKind::LoadSubtitle: {
-            QString filename = QFileDialog::getOpenFileName(this, tr("Open File"),
-                    QDir::currentPath(),
-                    tr("Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)"));
+            QString filename = QFileDialog::getOpenFileName(this, tr("Open file"),
+                    lastOpenedPath(),
+                    tr("Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)"));
             if (QFileInfo(filename).exists()) {
                 auto success = _engine->loadSubtitle(QFileInfo(filename));
                 _nwComm->updateWithMessage(success?tr("Load successfully"):tr("Load failed"));
@@ -1903,7 +1913,7 @@ void MainWindow::requestAction(ActionFactory::ActionKind kd, bool fromUI,
                 _nwShot->setAnchorPoint(QPoint(30, 38));
             }
             auto pm = utils::LoadHiDPIPixmap(QString(":/resources/icons/%1.svg").arg(success?"success":"fail"));
-            auto msg = success?tr("The screenshot is saved"):tr("The screenshot is failed to save");
+            auto msg = success?tr("The screenshot is saved"):tr("Failed to save the screenshot");
             _nwShot->popupWithIcon(msg, pm);
 #endif
             break;
@@ -2568,6 +2578,21 @@ void MainWindow::prepareSplashImages()
     bg_light = utils::LoadHiDPIImage(":/resources/icons/light/init-splash.svg");
 }
 
+QString MainWindow::lastOpenedPath()
+{
+    QString lastPath = Settings::get().generalOption("last_open_path").toString();
+    QDir lastDir(lastPath);
+    if (lastPath.isEmpty() || !lastDir.exists()) {
+        lastPath = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation);
+        QDir newLastDir(lastPath);
+        if (!newLastDir.exists()) {
+            lastPath = QDir::currentPath();
+        }
+    }
+
+    return lastPath;
+}
+
 void MainWindow::paintEvent(QPaintEvent* pe)
 {
     QPainter p(this);
@@ -2769,8 +2794,30 @@ void MainWindow::dropEvent(QDropEvent *ev)
         return;
     }
 
-    auto urls = ev->mimeData()->urls();
-    auto valids = _engine->addPlayFiles(urls);
+    QList<QUrl> urls = ev->mimeData()->urls();
+    QList<QUrl> valids = _engine->addPlayFiles(urls);
+
+    if (urls.count() == 1 && valids.count() == 0) {
+        // check if the dropped file is a subtitle.
+        QFileInfo fileInfo(urls.first().toLocalFile());
+        if (_engine->subtitle_suffixs.contains(fileInfo.suffix())) {
+            bool succ = _engine->loadSubtitle(fileInfo);
+            // notice that the file loaded but won't automatically selected.
+            const PlayingMovieInfo& pmf = _engine->playingMovieInfo();
+            for (const SubtitleInfo& sub: pmf.subs) {
+                if (sub["external"].toBool()) {
+                    QString path = sub["external-filename"].toString();
+                    if (path == fileInfo.canonicalFilePath()) {
+                        _engine->selectSubtitle(pmf.subs.indexOf(sub));
+                        break;
+                    }
+                }
+            }
+            QPixmap icon = utils::LoadHiDPIPixmap(QString(":/resources/icons/%1.svg").arg(succ ? "success" : "fail"));
+            _nwComm->popupWithIcon(succ ? tr("Load successfully") : tr("Load failed"), icon);
+        }
+        return;
+    }
 
     {
         auto all = urls.toSet();
