@@ -19,8 +19,8 @@
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="130"/>
-        <source>Open Folder</source>
-        <translation>Отвори Папка</translation>
+        <source>Open folder</source>
+        <translation>Отваряне на папка</translation>
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="121"/>
@@ -151,8 +151,8 @@
     </message>
     <message>
         <location filename="../common/settings_translation.cpp" line="31"/>
-        <source>volume down</source>
-        <translation>Намаляване на звука</translation>
+        <source>Volume down</source>
+        <translation>Намаляване</translation>
     </message>
     <message>
         <location filename="../common/settings_translation.cpp" line="32"/>
@@ -250,23 +250,12 @@
 </context>
 <context>
     <name>dmr::ActionFactory</name>
-    <message>
-        <location filename="../common/actions.cpp" line="82"/>
-        <location filename="../common/actions.cpp" line="102"/>
-        <source>Open File</source>
-        <translation>Отвори файл</translation>
-    </message>
     <message>
         <location filename="../common/actions.cpp" line="84"/>
         <location filename="../common/actions.cpp" line="269"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
-    <message>
-        <location filename="../common/actions.cpp" line="85"/>
-        <source>Light Theme</source>
-        <translation>Светла тема</translation>
-    </message>
     <message>
         <location filename="../common/actions.cpp" line="108"/>
         <source>Fullscreen</source>
@@ -282,11 +271,22 @@
         <source>Film info</source>
         <translation>Информация за филм</translation>
     </message>
+    <message>
+        <location filename="../common/actions.cpp" line="82"/>
+        <location filename="../common/actions.cpp" line="102"/>
+        <source>Open file</source>
+        <translation>Отвори файл</translation>
+    </message>
     <message>
         <location filename="../common/actions.cpp" line="83"/>
         <location filename="../common/actions.cpp" line="103"/>
-        <source>Open Folder</source>
-        <translation>Отвори Папка</translation>
+        <source>Open folder</source>
+        <translation>Отваряне на папка</translation>
+    </message>
+    <message>
+        <location filename="../common/actions.cpp" line="85"/>
+        <source>Light theme</source>
+        <translation>Светла тема</translation>
     </message>
     <message>
         <location filename="../common/actions.cpp" line="104"/>
@@ -441,7 +441,7 @@
     <message>
         <location filename="../common/actions.cpp" line="267"/>
         <source>Playlist</source>
-        <translation>Списък</translation>
+        <translation>Плейлист</translation>
     </message>
     <message>
         <location filename="../common/actions.cpp" line="268"/>
@@ -463,150 +463,166 @@
     <name>dmr::BurstScreenshotsDialog</name>
     <message>
         <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
-        <source>duration: %1</source>
-        <translation>времетраене: %1</translation>
+        <source>Duration: %1</source>
+        <translation>Продължителност: %1</translation>
     </message>
     <message>
         <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
-        <source>resolution: %1</source>
-        <translation>резолюция: %1</translation>
+        <source>Resolution: %1</source>
+        <translation>Резолюция: %1</translation>
     </message>
     <message>
         <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
-        <source>size: %1</source>
-        <translation>размер: %1</translation>
+        <source>Size: %1</source>
+        <translation>Размер: %1</translation>
     </message>
     <message>
         <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
-        <source>save</source>
-        <translation>запази</translation>
+        <source>Save</source>
+        <translation>Запазване</translation>
     </message>
 </context>
 <context>
     <name>dmr::MainWindow</name>
     <message>
-        <location filename="../common/mainwindow.cpp" line="785"/>
-        <location filename="../common/mainwindow.cpp" line="2284"/>
-        <location filename="../common/mainwindow.cpp" line="2381"/>
-        <source>Deepin Movie</source>
-        <translation>Deepin Филми</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="698"/>
-        <location filename="../common/mainwindow.cpp" line="1789"/>
+        <location filename="../common/mainwindow.cpp" line="720"/>
+        <location filename="../common/mainwindow.cpp" line="1821"/>
         <source>Load successfully</source>
         <translation>Успешно зареждане</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="698"/>
-        <location filename="../common/mainwindow.cpp" line="1789"/>
+        <location filename="../common/mainwindow.cpp" line="720"/>
+        <location filename="../common/mainwindow.cpp" line="1821"/>
         <source>Load failed</source>
         <translation>Неуспешно зареждане</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1392"/>
+        <location filename="../common/mainwindow.cpp" line="1424"/>
         <source>No device found</source>
         <translation>Не е открито устройство</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1410"/>
+        <location filename="../common/mainwindow.cpp" line="1442"/>
         <source>Parse Failed</source>
         <translation>Разборът е неуспешен</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1417"/>
-        <source>Open Folder</source>
-        <translation>Отвори Папка</translation>
+        <location filename="../common/mainwindow.cpp" line="1449"/>
+        <source>Open folder</source>
+        <translation>Отваряне на папка</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1432"/>
-        <location filename="../common/mainwindow.cpp" line="1449"/>
-        <location filename="../common/mainwindow.cpp" line="1784"/>
-        <source>Open File</source>
+        <location filename="../common/mainwindow.cpp" line="1464"/>
+        <location filename="../common/mainwindow.cpp" line="1481"/>
+        <location filename="../common/mainwindow.cpp" line="1816"/>
+        <source>Open file</source>
         <translation>Отвори файл</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1434"/>
-        <location filename="../common/mainwindow.cpp" line="1451"/>
+        <location filename="../common/mainwindow.cpp" line="1466"/>
+        <location filename="../common/mainwindow.cpp" line="1483"/>
         <source>All videos (%1)</source>
         <translation>Всички видеа (%1)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1652"/>
+        <location filename="../common/mainwindow.cpp" line="1684"/>
         <source>Muted</source>
         <translation>Заглушаване</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1655"/>
-        <location filename="../common/mainwindow.cpp" line="1667"/>
-        <location filename="../common/mainwindow.cpp" line="1677"/>
-        <location filename="../common/mainwindow.cpp" line="1684"/>
+        <location filename="../common/mainwindow.cpp" line="1687"/>
+        <location filename="../common/mainwindow.cpp" line="1699"/>
+        <location filename="../common/mainwindow.cpp" line="1709"/>
+        <location filename="../common/mainwindow.cpp" line="1716"/>
         <source>Volume: %1%</source>
         <translation>Сила на звука: %1</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1749"/>
-        <location filename="../common/mainwindow.cpp" line="1757"/>
+        <location filename="../common/mainwindow.cpp" line="1781"/>
+        <location filename="../common/mainwindow.cpp" line="1789"/>
         <source>Subtitle %1: %2s</source>
         <translation>Субтитри %1: %2s</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1750"/>
-        <location filename="../common/mainwindow.cpp" line="1758"/>
+        <location filename="../common/mainwindow.cpp" line="1782"/>
+        <location filename="../common/mainwindow.cpp" line="1790"/>
         <source>delayed</source>
         <translation>забавен</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1750"/>
-        <location filename="../common/mainwindow.cpp" line="1758"/>
+        <location filename="../common/mainwindow.cpp" line="1782"/>
+        <location filename="../common/mainwindow.cpp" line="1790"/>
         <source>advanced</source>
-        <translation>разпирен</translation>
+        <translation>разширен</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1765"/>
-        <location filename="../common/mainwindow.cpp" line="1772"/>
-        <location filename="../common/mainwindow.cpp" line="1779"/>
+        <location filename="../common/mainwindow.cpp" line="1797"/>
+        <location filename="../common/mainwindow.cpp" line="1804"/>
+        <location filename="../common/mainwindow.cpp" line="1811"/>
         <source>Speed: %1x</source>
         <translation>Скорост: %1x</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1786"/>
-        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</source>
-        <translation>Субтитри (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</translation>
+        <location filename="../common/mainwindow.cpp" line="1818"/>
+        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
+        <translation>Субтитри (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1848"/>
+        <location filename="../common/mainwindow.cpp" line="1880"/>
         <source>View</source>
         <translation>Изглед</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1859"/>
+        <location filename="../common/mainwindow.cpp" line="1891"/>
         <source>Movie Screenshot</source>
         <translation>Снимка на филма</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1860"/>
+        <location filename="../common/mainwindow.cpp" line="1892"/>
         <source>Saved to</source>
         <translation>Запази в</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1874"/>
-        <location filename="../common/mainwindow.cpp" line="1957"/>
+        <location filename="../common/mainwindow.cpp" line="1906"/>
+        <location filename="../common/mainwindow.cpp" line="1989"/>
         <source>The screenshot is saved</source>
         <translation>Снимка на екрана е запазена.</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1874"/>
-        <source>The screenshot is failed to save</source>
-        <translation>Снимка на екрана не е запазена.</translation>
+        <location filename="../common/mainwindow.cpp" line="1906"/>
+        <source>Failed to save the screenshot</source>
+        <translation>Не може да се запази снимка на кадъра</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="2044"/>
-        <location filename="../common/mainwindow.cpp" line="2741"/>
+        <location filename="../common/mainwindow.cpp" line="2076"/>
+        <location filename="../common/mainwindow.cpp" line="2782"/>
         <source>Invalid file: %1</source>
         <translation>Невалиден файл: %1</translation>
     </message>
 </context>
+<context>
+    <name>dmr::MovieInfo</name>
+    <message>
+        <location filename="../libdmr/playlist_model.h" line="67"/>
+        <source>%1G</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../libdmr/playlist_model.h" line="69"/>
+        <source>%1M</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../libdmr/playlist_model.h" line="71"/>
+        <source>%1K</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../libdmr/playlist_model.h" line="73"/>
+        <source>%1</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>dmr::MovieInfoDialog</name>
     <message>
@@ -638,8 +654,8 @@
 <context>
     <name>dmr::MpvProxy</name>
     <message>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1029"/>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1047"/>
+        <location filename="../backends/mpv/mpv_proxy.cpp" line="1034"/>
+        <location filename="../backends/mpv/mpv_proxy.cpp" line="1052"/>
         <source>[internal]</source>
         <translation>[вътрешен]</translation>
     </message>
