@@ -19,7 +19,7 @@
     </message>
     <message>
         <location filename="../common/mainwindow.cpp" line="130"/>
-        <source>Open Folder</source>
+        <source>Open folder</source>
         <translation>Otvoriť priečinok</translation>
     </message>
     <message>
@@ -151,8 +151,8 @@
     </message>
     <message>
         <location filename="../common/settings_translation.cpp" line="31"/>
-        <source>volume down</source>
-        <translation>znížiť hlasitosť</translation>
+        <source>Volume down</source>
+        <translation>Tichšie</translation>
     </message>
     <message>
         <location filename="../common/settings_translation.cpp" line="32"/>
@@ -250,23 +250,12 @@
 </context>
 <context>
     <name>dmr::ActionFactory</name>
-    <message>
-        <location filename="../common/actions.cpp" line="82"/>
-        <location filename="../common/actions.cpp" line="102"/>
-        <source>Open File</source>
-        <translation>Otvoriť súbor</translation>
-    </message>
     <message>
         <location filename="../common/actions.cpp" line="84"/>
         <location filename="../common/actions.cpp" line="269"/>
         <source>Settings</source>
         <translation>Nastavenia</translation>
     </message>
-    <message>
-        <location filename="../common/actions.cpp" line="85"/>
-        <source>Light Theme</source>
-        <translation>Svetlá téma</translation>
-    </message>
     <message>
         <location filename="../common/actions.cpp" line="108"/>
         <source>Fullscreen</source>
@@ -282,11 +271,22 @@
         <source>Film info</source>
         <translation>Informácie o filme</translation>
     </message>
+    <message>
+        <location filename="../common/actions.cpp" line="82"/>
+        <location filename="../common/actions.cpp" line="102"/>
+        <source>Open file</source>
+        <translation>Otvoriť súbor</translation>
+    </message>
     <message>
         <location filename="../common/actions.cpp" line="83"/>
         <location filename="../common/actions.cpp" line="103"/>
-        <source>Open Folder</source>
-        <translation>Otvoriť adresár</translation>
+        <source>Open folder</source>
+        <translation>Otvoriť priečinok</translation>
+    </message>
+    <message>
+        <location filename="../common/actions.cpp" line="85"/>
+        <source>Light theme</source>
+        <translation>Svetlá téma</translation>
     </message>
     <message>
         <location filename="../common/actions.cpp" line="104"/>
@@ -463,150 +463,166 @@
     <name>dmr::BurstScreenshotsDialog</name>
     <message>
         <location filename="../widgets/burst_screenshots_dialog.cpp" line="88"/>
-        <source>duration: %1</source>
-        <translation>doba trvania: %1</translation>
+        <source>Duration: %1</source>
+        <translation>Doba trvania: %1</translation>
     </message>
     <message>
         <location filename="../widgets/burst_screenshots_dialog.cpp" line="94"/>
-        <source>resolution: %1</source>
-        <translation>rozlíšenie: %1</translation>
+        <source>Resolution: %1</source>
+        <translation>Rozlíšenie: %1</translation>
     </message>
     <message>
         <location filename="../widgets/burst_screenshots_dialog.cpp" line="100"/>
-        <source>size: %1</source>
-        <translation>veľkosť: %1</translation>
+        <source>Size: %1</source>
+        <translation>Veľkosť: %1</translation>
     </message>
     <message>
         <location filename="../widgets/burst_screenshots_dialog.cpp" line="123"/>
-        <source>save</source>
-        <translation>uložiť</translation>
+        <source>Save</source>
+        <translation>Uložiť</translation>
     </message>
 </context>
 <context>
     <name>dmr::MainWindow</name>
     <message>
-        <location filename="../common/mainwindow.cpp" line="785"/>
-        <location filename="../common/mainwindow.cpp" line="2284"/>
-        <location filename="../common/mainwindow.cpp" line="2381"/>
-        <source>Deepin Movie</source>
-        <translation>Deepin Filmy</translation>
-    </message>
-    <message>
-        <location filename="../common/mainwindow.cpp" line="698"/>
-        <location filename="../common/mainwindow.cpp" line="1789"/>
+        <location filename="../common/mainwindow.cpp" line="720"/>
+        <location filename="../common/mainwindow.cpp" line="1821"/>
         <source>Load successfully</source>
         <translation>Nahrávanie úspešné</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="698"/>
-        <location filename="../common/mainwindow.cpp" line="1789"/>
+        <location filename="../common/mainwindow.cpp" line="720"/>
+        <location filename="../common/mainwindow.cpp" line="1821"/>
         <source>Load failed</source>
         <translation>Nahrávanie zlyhalo</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1392"/>
+        <location filename="../common/mainwindow.cpp" line="1424"/>
         <source>No device found</source>
         <translation>Nebolo nájdené žiadne zariadenie</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1410"/>
+        <location filename="../common/mainwindow.cpp" line="1442"/>
         <source>Parse Failed</source>
         <translation>Spracovanie zlyhalo</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1417"/>
-        <source>Open Folder</source>
-        <translation>Otvoriť adresár</translation>
+        <location filename="../common/mainwindow.cpp" line="1449"/>
+        <source>Open folder</source>
+        <translation>Otvoriť priečinok</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1432"/>
-        <location filename="../common/mainwindow.cpp" line="1449"/>
-        <location filename="../common/mainwindow.cpp" line="1784"/>
-        <source>Open File</source>
+        <location filename="../common/mainwindow.cpp" line="1464"/>
+        <location filename="../common/mainwindow.cpp" line="1481"/>
+        <location filename="../common/mainwindow.cpp" line="1816"/>
+        <source>Open file</source>
         <translation>Otvoriť súbor</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1434"/>
-        <location filename="../common/mainwindow.cpp" line="1451"/>
+        <location filename="../common/mainwindow.cpp" line="1466"/>
+        <location filename="../common/mainwindow.cpp" line="1483"/>
         <source>All videos (%1)</source>
         <translation>Všetky videá (%1)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1652"/>
+        <location filename="../common/mainwindow.cpp" line="1684"/>
         <source>Muted</source>
         <translation>Stlmené</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1655"/>
-        <location filename="../common/mainwindow.cpp" line="1667"/>
-        <location filename="../common/mainwindow.cpp" line="1677"/>
-        <location filename="../common/mainwindow.cpp" line="1684"/>
+        <location filename="../common/mainwindow.cpp" line="1687"/>
+        <location filename="../common/mainwindow.cpp" line="1699"/>
+        <location filename="../common/mainwindow.cpp" line="1709"/>
+        <location filename="../common/mainwindow.cpp" line="1716"/>
         <source>Volume: %1%</source>
         <translation>Hlasitosť: %1%</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1749"/>
-        <location filename="../common/mainwindow.cpp" line="1757"/>
+        <location filename="../common/mainwindow.cpp" line="1781"/>
+        <location filename="../common/mainwindow.cpp" line="1789"/>
         <source>Subtitle %1: %2s</source>
         <translation>Titulky %1: %2s</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1750"/>
-        <location filename="../common/mainwindow.cpp" line="1758"/>
+        <location filename="../common/mainwindow.cpp" line="1782"/>
+        <location filename="../common/mainwindow.cpp" line="1790"/>
         <source>delayed</source>
         <translation>oneskorené</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1750"/>
-        <location filename="../common/mainwindow.cpp" line="1758"/>
+        <location filename="../common/mainwindow.cpp" line="1782"/>
+        <location filename="../common/mainwindow.cpp" line="1790"/>
         <source>advanced</source>
         <translation>pokročilé</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1765"/>
-        <location filename="../common/mainwindow.cpp" line="1772"/>
-        <location filename="../common/mainwindow.cpp" line="1779"/>
+        <location filename="../common/mainwindow.cpp" line="1797"/>
+        <location filename="../common/mainwindow.cpp" line="1804"/>
+        <location filename="../common/mainwindow.cpp" line="1811"/>
         <source>Speed: %1x</source>
         <translation>Rýchlosť: %1x</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1786"/>
-        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</source>
-        <translation>Titulky (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.usf *.idx)</translation>
+        <location filename="../common/mainwindow.cpp" line="1818"/>
+        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
+        <translation>Titulky (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1848"/>
+        <location filename="../common/mainwindow.cpp" line="1880"/>
         <source>View</source>
         <translation>Náhľad</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1859"/>
+        <location filename="../common/mainwindow.cpp" line="1891"/>
         <source>Movie Screenshot</source>
         <translation>Snímka obrazovky filmu</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1860"/>
+        <location filename="../common/mainwindow.cpp" line="1892"/>
         <source>Saved to</source>
         <translation>Uložené na</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1874"/>
-        <location filename="../common/mainwindow.cpp" line="1957"/>
+        <location filename="../common/mainwindow.cpp" line="1906"/>
+        <location filename="../common/mainwindow.cpp" line="1989"/>
         <source>The screenshot is saved</source>
         <translation>Snímok obrazovky sa uložil</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="1874"/>
-        <source>The screenshot is failed to save</source>
-        <translation>Snímok obrazovky sa nepodarilo uložiť</translation>
+        <location filename="../common/mainwindow.cpp" line="1906"/>
+        <source>Failed to save the screenshot</source>
+        <translation>Nepodarilo sa uložiť snímku obrazovky</translation>
     </message>
     <message>
-        <location filename="../common/mainwindow.cpp" line="2044"/>
-        <location filename="../common/mainwindow.cpp" line="2741"/>
+        <location filename="../common/mainwindow.cpp" line="2076"/>
+        <location filename="../common/mainwindow.cpp" line="2782"/>
         <source>Invalid file: %1</source>
         <translation>Neplatný súbor: %1</translation>
     </message>
 </context>
+<context>
+    <name>dmr::MovieInfo</name>
+    <message>
+        <location filename="../libdmr/playlist_model.h" line="67"/>
+        <source>%1G</source>
+        <translation>%1G</translation>
+    </message>
+    <message>
+        <location filename="../libdmr/playlist_model.h" line="69"/>
+        <source>%1M</source>
+        <translation>%1M</translation>
+    </message>
+    <message>
+        <location filename="../libdmr/playlist_model.h" line="71"/>
+        <source>%1K</source>
+        <translation>%1K</translation>
+    </message>
+    <message>
+        <location filename="../libdmr/playlist_model.h" line="73"/>
+        <source>%1</source>
+        <translation>%1</translation>
+    </message>
+</context>
 <context>
     <name>dmr::MovieInfoDialog</name>
     <message>
@@ -638,8 +654,8 @@
 <context>
     <name>dmr::MpvProxy</name>
     <message>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1029"/>
-        <location filename="../backends/mpv/mpv_proxy.cpp" line="1047"/>
+        <location filename="../backends/mpv/mpv_proxy.cpp" line="1034"/>
+        <location filename="../backends/mpv/mpv_proxy.cpp" line="1052"/>
         <source>[internal]</source>
         <translation>[vnútorné]</translation>
     </message>
